@@ -483,6 +483,11 @@ class XRasterBase(XGeoBase):
             bounds = self.bounds
         return bounds
 
+    def flipud(self):
+        """Returns raster flipped along y-axis"""
+        yrev = list(reversed(self.ycoords))
+        return self._obj.reindex({self.y_dim: yrev})
+
     def rowcol(self, xs, ys, mask=None, mask_outside=False, nodata=-1):
         """Return row, col indices of x, y coordinates
 
@@ -618,6 +623,7 @@ class XRasterBase(XGeoBase):
         ojb_out: xr.Dataset or xr.DataArray
             Output sample data
         """
+        # TODO: add method for line geometries
         if not np.all(gdf.geometry.type == "Point"):
             raise ValueError("Only point geometries accepted")
 
@@ -644,7 +650,7 @@ class XRasterBase(XGeoBase):
                     self.x_dim: xr.Variable(("index", "wdw"), cwdw),
                     self.y_dim: xr.Variable(("index", "wdw"), rwdw),
                 }
-            ).set_coords("mask")
+            )
         else:
             ds_sel = xr.Dataset(
                 {
@@ -653,15 +659,10 @@ class XRasterBase(XGeoBase):
                     self.x_dim: xr.Variable("index", c),
                     self.y_dim: xr.Variable("index", r),
                 }
-            ).set_coords("mask")
-        obj_out = self._obj.isel(ds_sel)
-        if True or np.any(obj_out["mask"]):
-            if isinstance(obj_out, xr.DataArray):
-                obj_out = obj_out.where(obj_out["mask"], obj_out.raster.nodata)
-            else:
-                for var in obj_out.data_vars:
-                    nodata = obj_out[var].raster.nodata
-                    obj_out[var] = obj_out[var].where(obj_out["mask"], nodata)
+            )
+        obj_out = self._obj.isel(ds_sel[[self.y_dim, self.x_dim]])
+        if np.any(~ds_sel["mask"]):  # mask out of domain points
+            obj_out = obj_out.raster.mask(ds_sel["mask"])
         return obj_out
 
     def zonal_stats(self, gdf, stats, all_touched=False):
@@ -977,6 +978,53 @@ class XRasterBase(XGeoBase):
                 cells.append(box(left, bottom, right, top))
         return gpd.GeoDataFrame(geometry=cells, crs=self.crs)
 
+    def area_grid(self, dtype=np.float32):
+        """Returns the grid cell area [m2].
+
+        Returns
+        -------
+        da_area : xarray.DataArray
+            Grid cell surface area [m2].
+        """
+        if self.crs.is_geographic:
+            data = gis_utils.reggrid_area(self.ycoords.values, self.xcoords.values)
+        elif self.crs.is_projected:
+            xres = abs(self.res[0]) * self.crs.linear_units_factor[1]
+            yres = abs(self.res[1]) * self.crs.linear_units_factor[1]
+            data = np.full(self.shape, xres * yres)
+        da_area = xr.DataArray(
+            data=data.astype(dtype), coords=self.coords, dims=self.dims
+        )
+        da_area.raster.set_nodata(0)
+        da_area.raster.set_crs(self.crs)
+        da_area.attrs.update(unit="m2")
+        return da_area.rename("area")
+
+    def density_grid(self):
+        """Returns the density in [unit/m2] of raster(s). The cell areas are calculated
+        using :py:meth:`~hydromt.raster.XRasterBase.area_grid`.
+
+        Returns
+        -------
+        ds_out: xarray.DataArray or xarray.DataSet
+            The density in [unit/m2] of the raster.
+        """
+
+        # Create a grid that contains the area in m2 per grid cell.
+        if self.crs.is_geographic:
+            area = self.area_grid()
+
+        elif self.crs.is_projected:
+            xres = abs(self.res[0]) * self.crs.linear_units_factor[1]
+            yres = abs(self.res[1]) * self.crs.linear_units_factor[1]
+            area = xres * yres
+
+        # Create a grid that contains the density in unit/m2 per grid cell.
+        unit = self._obj.attrs.get("unit", "")
+        ds_out = self._obj / area
+        ds_out.attrs.update(unit=f"{unit}.m-2")
+        return ds_out
+
     def _dst_transform(
         self,
         dst_crs=None,
